<?php
/**
*  @author reybex <info@editsystems.com>
*  @copyright  2020 reybex
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

include_once dirname(__FILE__) . '/classes/ReybexInvoice.php';

class upload_reybex_invoice extends Module
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'upload_reybex_invoice';
        $this->tab = 'billing_invoicing';
        $this->version = '1.2.6';
        $this->author = 'reybex';
        $this->need_instance = 1;
        $this->module_key = 'c1a25f46188ff7f4862b0700ee04bd41';

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Invoice Uploading with reybex');
        $this->description = $this->l('You can upload your invoice with reybex');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall Invoice Uploading with reybex module?');

        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => '1.6.5');
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        Configuration::updateValue('UPLOAD_REYBEX_INVOICE_LIVE_MODE', false);

        include(dirname(__FILE__).'/sql/install.php');

        return parent::install() 
            && $this->registerHook('displayAdminOrderTabOrder')
            && $this->registerHook('displayAdminOrderContentOrder');
    }

    public function uninstall()
    {
        Configuration::deleteByName('UPLOAD_REYBEX_INVOICE_LIVE_MODE');

        include(dirname(__FILE__).'/sql/uninstall.php');

        return parent::uninstall();
    }

    public function hookDisplayAdminOrderContentOrder($params)
    {
        $link = new Link();
        $url = $link-> getPageLink('pdf-invoice', true, NULL, "id_order=".$params['order']->id);
        $reybex_invoices = [];
        $order_invoice_list = $params['order']->getInvoicesCollection();
        if(count($order_invoice_list) > 0){
            $id_lang = Context::getContext()->language->id;
            $id_shop = (int)$params['order']->id_shop;
            $format = '%1$s%2$06d';
            $filename = sprintf( $format, Configuration::get('PS_INVOICE_PREFIX', $id_lang, null, $id_shop), 
                $order_invoice_list[0]->number, 
                date('Y', strtotime($order_invoice_list[0]->date_add)));
            $filename = 'RX-'.$filename;

            $reybex_invoices = Db::getInstance()->executeS(' SELECT url,date_add,note FROM `'._DB_PREFIX_.'reybex_invoice`
                WHERE `id_order` = '.(int)$params['order']->id);
        }

        if(count($reybex_invoices) > 0){
            $reybex_invoice_tab_content = '<table class="table" id="reybex_invoices_table">
            <thead>
                <tr>
                    <th><span class="title_box ">Invoice</span></th>
                    <th><span class="title_box ">Note</span></th>
                    <th><span class="title_box ">Date</span></th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <td><span class="title_box "><a class="_blank" title="asd" href="'.$url.'">'.$filename.'</a></span></td>
                    <td><span class="title_box ">'.$reybex_invoices[0]['note'].'</span></td>
                    <td><span class="title_box ">'.$reybex_invoices[0]['date_add'].'</span></td>
                </tr>
            </tbody></table>';
            return '<div class="tab-pane" id="reybexInvoices">'.$reybex_invoice_tab_content.'</div>';
        } else {
            return null;
        }
    }

    public function hookDisplayAdminOrderTabOrder($params)
    {
        $order_invoice_list = $params['order']->getInvoicesCollection();
        if(count($order_invoice_list) > 0){
            $reybex_invoices = Db::getInstance()->executeS(' SELECT url,date_add,note FROM `'._DB_PREFIX_.'reybex_invoice`
                WHERE `id_order` = '.(int)$params['order']->id);

            if(count($reybex_invoices) > 0){
                return '<li><a href="#reybexInvoices"><i class="icon-file-text"></i> reybex Invoices <span class="badge">1</span></a></li>';
            } else {
                return null;
            }
        } else {
            return null;
        }
    }
}
