<?php
/**
* 2007-2020 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2020 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

include_once dirname(__FILE__) . '/classes/ReybexInvoice.php';

class Upload_reybex_invoice extends Module
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'upload_reybex_invoice';
        $this->tab = 'front_office_features';
        $this->version = '1.2.6';
        $this->author = 'reybex';
        $this->need_instance = 1;

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Invoice Uploading with reybex');
        $this->description = $this->l('You can upload your invoice with reybex');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall Invoice Uploading with reybex module?');

        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        Configuration::updateValue('UPLOAD_REYBEX_INVOICE_LIVE_MODE', false);

        include(dirname(__FILE__).'/sql/install.php');

        return parent::install() &&
            $this->registerHook('displayBackOfficeOrderActions') &&
            $this->registerHook('addWebserviceResources');
    }

    public function uninstall()
    {
        Configuration::deleteByName('UPLOAD_REYBEX_INVOICE_LIVE_MODE');

        include(dirname(__FILE__).'/sql/uninstall.php');

        return parent::uninstall();
    }

    public function hookAddWebserviceResources($params)
    {
        return array(
            'reybex_invoices' => array('description' => 'reybex_invoices', 'class' => 'ReybexInvoice')
        );
    }

    public function hookDisplayBackOfficeOrderActions($params)
    {
        $id_order = $params["id_order"];
        $url = Db::getInstance()->getValue(' SELECT url FROM `'._DB_PREFIX_.'reybex_invoice`
            WHERE `id_order` = '.(int)$id_order);
        if (isset($url) && $url != '') {
            return '<a id="desc-order-partial_refund" class="btn btn-default" href="'.$url.'" target="_blank">
              <i class="icon-file"></i> Reybex Invoice</a>';
        } else {
            return null;
        }
    }
}
